﻿using System;
using System.Web;
using System.Web.Mvc;
using HttpContextUnitTestSample.Controllers;
using HttpContextUnitTestSample.DemoStuff;
using HttpContextUnitTestSample.Models;
using NUnit.Framework;
using Rhino.Mocks;

namespace HttpContextUnitTestSample.Specs
{
    [TestFixture]
    [Category("HttpContextUnitTestSample.Controllers.LoginController")]
    public class Wenn_sich_ein_Benutzer_erfolgreich_einloggt_und_eine_ReturnUrl_angegeben_ist : ConcernOf<LoginController>
    {

        protected IAuthenticationService AuthenticationService;
        protected HttpContextBase HttpContext;
        protected HttpRequestBase HttpRequest;

        public override void Setup()
        {

            AuthenticationService = MockRepository.DynamicMock<IAuthenticationService>();
            HttpContext = MockRepository.DynamicMock<HttpContextBase>();
            HttpRequest = MockRepository.DynamicMock<HttpRequestBase>();
            
            Sut = new LoginController(AuthenticationService, HttpContext);

            using (MockRepository.Record())
            {
                Expect.Call(AuthenticationService.ValidateLogin(Arg<string>.Is.Equal("valid"), Arg<string>.Is.Equal("password"), Arg<IValidationState>.Is.Anything)).Return(true).Repeat.Any();
                HttpContext.Expect(c => c.Request).Return(HttpRequest).Repeat.Any();
            }

        }

        [Test]
        public void Wird_zu_dieser_weitergeleitet_sofern_es_eine_interne_Url_ist()
        {

            HttpRequest.BackToRecord(BackToRecordOptions.Expectations);
            using (MockRepository.Record())
            {
                HttpRequest.Expect(r => r.QueryString["ReturnUrl"]).Return("/usermanagement");
            }

            var result = (RedirectResult)Sut.Index(new LoginViewModel { UserName = "valid", Password = "password" });
            Assert.AreEqual("/usermanagement", result.Url);

        }

        [Test]
        public void Wird_zur_Startseite_weitergeleitet_wenn_sie_nicht_mit_einem_Slash_beginnt()
        {

            HttpRequest.BackToRecord(BackToRecordOptions.Expectations);
            using (MockRepository.Record())
            {
                HttpRequest.Expect(r => r.QueryString["ReturnUrl"]).Return("http://phishingurl.com");
            }

            var result = (RedirectToRouteResult)Sut.Index(new LoginViewModel { UserName = "valid", Password = "password" });
            Assert.AreEqual("home", result.RouteValues["controller"]);

        }

    }

}
