﻿using System.Web;
using System.Web.Mvc;
using System.Web.Routing;
using HttpContextUnitTestSample.DemoStuff;
using StructureMap;
using StructureMap.Configuration.DSL;

namespace HttpContextUnitTestSample
{
    public class Bootstrapper
    {

        public static void Bootstrap()
        {

            ObjectFactory.Initialize(c =>
            {
                c.AddRegistry(new FrameworkInfrastructureRegistry());
				c.AddRegistry(new DemoStuffRegistry());
            });


            ControllerBuilder.Current.SetControllerFactory(new StructureMapControllerFactory());
            AreaRegistration.RegisterAllAreas();
            RegisterRoutes(RouteTable.Routes);

        }

        private class FrameworkInfrastructureRegistry : Registry
        {
            public FrameworkInfrastructureRegistry()
            {
                For<HttpContextBase>().Use(() => new HttpContextWrapper(HttpContext.Current));
            }
        }

        private class DemoStuffRegistry : Registry
        {
            public DemoStuffRegistry()
            {
                For<IAuthenticationService>().Use<FormsAuthenticationService>();
            }
        }

        public static void RegisterRoutes(RouteCollection routes)
        {
            routes.IgnoreRoute("{resource}.axd/{*pathInfo}");
            routes.MapRoute(
                "Default", // Route name
                "{controller}/{action}/{id}", // URL with parameters
                new { controller = "Home", action = "Index", id = UrlParameter.Optional } // Parameter defaults
            );
        }

    }
}