﻿using System.Web;
using System.Web.Mvc;
using HttpContextUnitTestSample.Models;
using HttpContextUnitTestSample.DemoStuff;

namespace HttpContextUnitTestSample.Controllers
{
    public class LoginController : Controller
    {

        public LoginController(IAuthenticationService authenticationService, HttpContextBase httpContext)
        {
            AuthenticationService = authenticationService;
            HttpContext = httpContext;
        }

        private readonly IAuthenticationService AuthenticationService;
        private new readonly HttpContextBase HttpContext;

        [HttpGet]
        public ActionResult Index()
        {
            return View(new LoginViewModel());
        }

        [HttpPost]
        public ActionResult Index(LoginViewModel model)
        {

            if (AuthenticationService.ValidateLogin(model.UserName, model.Password, new ViewModelValidationState(ModelState)))
            {
                
                AuthenticationService.SignIn(model.UserName);

                string returnUrl = HttpContext.Request.QueryString["ReturnUrl"];
                if (!string.IsNullOrWhiteSpace(returnUrl) && returnUrl.StartsWith("/"))
                    return Redirect(returnUrl);

                return RedirectToAction("index", "home");

            }

            return View();

        }

    }
}
